@@ -146,7 +146,6 @@ use Goo::Object;
 =head1 DESCRIPTION
 
 
-
 =head1 METHODS
 
 =over
@@ -169,18 +168,17 @@ return the type of this object
 
 =item to_string
 
-return a string representation of this class
+return a string representation of this object
 
 =item to_htmlstring
 
-return a html representation of this class
-
+return a HTML representation of this object
 
 =back
 
 =head1 AUTHOR
 
-Nigel Hamilton <nigel@turbo10.com>
+Nigel Hamilton <nigel@trexy.com>
 
 =head1 SEE ALSO
 
